@@ -178,7 +178,7 @@ class CloudControlApiClient(BaseClient):
         *,
         MaxResults: int = ...,
         NextToken: str = ...,
-        ResourceRequestStatusFilter: "ResourceRequestStatusFilterTypeDef" = ...
+        ResourceRequestStatusFilter: ResourceRequestStatusFilterTypeDef = ...
     ) -> ListResourceRequestsOutputTypeDef:
         """
         Returns existing resource operation requests.
